#ifndef __TP_META_SVC_CONNECTION_MANAGER_H__
#define __TP_META_SVC_CONNECTION_MANAGER_H__

#include <telepathy-glib/_gen/tp-svc-connection-manager-interfaces.h>

#endif
